@@ -24,8 +24,11 @@ import time
 
 from datetime import datetime
 from datetime import timedelta
+import os_traits
 from oslo_log import log
+from tempest.common import waiters
 from tempest import config
+from tempest.lib.common import api_microversion_fixture
 from tempest.lib.common.utils import data_utils
 from tempest.lib.common.utils import test_utils
 from tempest.lib import exceptions
@@ -58,6 +61,14 @@ class BaseInfraOptimScenarioTest(manager.ScenarioTest):
         super(BaseInfraOptimScenarioTest, cls).setup_clients()
         cls.client = cls.mgr.io_client
         cls.gnocchi = cls.mgr.gn_client
+        cls.placement_client = cls.mgr.placement_client
+
+    def setUp(self):
+        super(BaseInfraOptimScenarioTest, self).setUp()
+        self.useFixture(api_microversion_fixture.APIMicroversionFixture(
+            compute_microversion=CONF.compute.min_microversion))
+        self.useFixture(api_microversion_fixture.APIMicroversionFixture(
+            placement_microversion=CONF.placement.min_microversion))
 
     @classmethod
     def resource_setup(cls):
@@ -120,11 +131,13 @@ class BaseInfraOptimScenarioTest(manager.ScenarioTest):
             ]
             initial_cn_setup = matching_cns[0]  # Should return a single result
             if cn_setup.get('status') != initial_cn_setup.get('status'):
-                if initial_cn_setup.get('status') == 'enabled':
-                    rollback_func = cls.mgr.services_client.enable_service
-                else:
-                    rollback_func = cls.mgr.services_client.disable_service
-                rollback_func(binary='nova-compute', host=cn_hostname)
+                svr_id = cn_setup.get('id')
+                status = initial_cn_setup.get('status')
+                # The Nova version Watcher neede is at least 2.56
+                # Starting with microversion 2.53 disable/enable API
+                # is superseded by PUT /os-services/{service_id}
+                rollback_func = cls.mgr.services_client.update_service
+                rollback_func(svr_id, status=status)
 
     @classmethod
     def wait_for(cls, condition, timeout=30):
@@ -154,17 +167,31 @@ class BaseInfraOptimScenarioTest(manager.ScenarioTest):
             sleep_for=5
         )
 
-    def _migrate_server_to(self, server_id, dest_host, volume_backed=False):
-        kwargs = dict()
-        kwargs['disk_over_commit'] = False
-        block_migration = (CONF.compute_feature_enabled.
-                           block_migration_for_live_migration and
-                           not volume_backed)
+    def _migrate_server_to(self, server_id, dest_host):
+        # The default value of  block_migration is auto and
+        # disk_over_commit is not valid after version 2.25
+        block_migration = 'auto'
         body = self.mgr.servers_client.live_migrate_server(
-            server_id, host=dest_host, block_migration=block_migration,
-            **kwargs)
+            server_id, host=dest_host, block_migration=block_migration)
         return body
 
+    def _live_migrate(self, server_id, target_host, state):
+        self._migrate_server_to(server_id, target_host)
+        waiters.wait_for_server_status(self.servers_client, server_id, state)
+        migration_list = (self.mgr.migrations_client.list_migrations()
+                          ['migrations'])
+
+        msg = ("Live Migration failed. Migrations list for Instance "
+               "%s: [" % server_id)
+        for live_migration in migration_list:
+            if (live_migration['instance_uuid'] == server_id):
+                msg += "\n%s" % live_migration
+        msg += "]"
+        server_host = self.mgr.servers_client.show_server(
+            server_id)['server']['OS-EXT-SRV-ATTR:host']
+
+        self.assertEqual(target_host, server_host, msg)
+
     def _create_one_instance_per_host_with_statistic(self, metrics=dict()):
         """Create 1 instance per compute node and make instance statistic
 
@@ -173,12 +200,34 @@ class BaseInfraOptimScenarioTest(manager.ScenarioTest):
 
         :param metrics: The metrics add to resource when using Gnocchi
         """
-        host_client = self.mgr.hosts_client
-        all_hosts = host_client.list_hosts()['hosts']
-        compute_nodes = [x for x in all_hosts if x['service'] == 'compute']
+        compute_nodes = self.get_compute_nodes_setup()
+        instances = self.mgr.servers_client.list_servers(
+            detail=True)['servers']
+        if instances:
+            return instances
 
+        hypervisors = self.get_hypervisors_setup()
         created_instances = []
-        for _ in compute_nodes[:CONF.compute.min_compute_nodes]:
+        for node in compute_nodes[:CONF.compute.min_compute_nodes]:
+            hyp_id = [
+                hyp['id'] for hyp in hypervisors
+                if hyp['hypervisor_hostname'] == node['host']]
+            # Placement may fail to update trait because of Conflict
+            # the trait may be updated by the Nova compute
+            # update_available_resource periodic task.
+            # We need node status is enabled, so we check the node
+            # trait and delay if it is not the correct status.
+            # the max delay time is 10 minutes.
+            node_trait = os_traits.COMPUTE_STATUS_DISABLED
+            retry = 20
+            trait_status = True
+            while trait_status and retry:
+                trait_status = self.check_node_trait(hyp_id[0], node_trait)
+                if not trait_status:
+                    break
+                time.sleep(30)
+                retry -= 1
+            self.assertNotEqual(0, retry)
             # by getting to active state here, this means this has
             # landed on the host in question.
             instance = self.create_server(image_id=CONF.compute.image_ref,
@@ -199,7 +248,7 @@ class BaseInfraOptimScenarioTest(manager.ScenarioTest):
         node = hypervisors[0]
         for instance in instances:
             if instance.get('OS-EXT-SRV-ATTR:hypervisor_hostname') != node:
-                self._migrate_server_to(instance['id'], node)
+                self._live_migrate(instance['id'], node, 'ACTIVE')
 
     # ### GNOCCHI ### #
 
@@ -288,8 +337,9 @@ class BaseInfraOptimScenarioTest(manager.ScenarioTest):
         :param instance: Instance response body
         :param metrics: The metrics add to resource when using Gnocchi
         """
-        flavor = self.flavors_client.show_flavor(instance['flavor']['id'])
-        flavor_name = flavor['flavor']['name']
+        all_flavors = self.flavors_client.list_flavors()['flavors']
+        flavor_name = instance['flavor']['original_name']
+        flavor = [f for f in all_flavors if f['name'] == flavor_name]
         if metrics == dict():
             metrics = {
                 'cpu_util': {
@@ -302,7 +352,7 @@ class BaseInfraOptimScenarioTest(manager.ScenarioTest):
             'host': instance.get('OS-EXT-SRV-ATTR:hypervisor_hostname'),
             'display_name': instance.get('OS-EXT-SRV-ATTR:instance_name'),
             'image_ref': instance['image']['id'],
-            'flavor_id': instance['flavor']['id'],
+            'flavor_id': flavor[0]['id'],
             'flavor_name': flavor_name,
             'id': instance['id']
         }
@@ -418,3 +468,92 @@ class BaseInfraOptimScenarioTest(manager.ScenarioTest):
             if action_plan.get('state') not in self.AP_FINISHED_STATES:
                 return False
         return True
+
+    def execute_strategy(self, goal_name, strategy_name, **audit_kwargs):
+        """Execute an action plan based on the specific strategy
+
+        - create an audit template with the specific strategy
+        - run the audit to create an action plan
+        - get the action plan
+        - run the action plan
+        - get results and make sure it succeeded
+        """
+        _, goal = self.client.show_goal(goal_name)
+        _, strategy = self.client.show_strategy(strategy_name)
+        _, audit_template = self.create_audit_template(
+            goal['uuid'], strategy=strategy['uuid'])
+
+        self.assertTrue(test_utils.call_until_true(
+            func=functools.partial(
+                self.has_action_plans_finished),
+            duration=600,
+            sleep_for=2
+        ))
+
+        audit_type = audit_kwargs.pop('audit_type', 'ONESHOT')
+        state = audit_kwargs.pop('state', None)
+        interval = audit_kwargs.pop('interval', None)
+        parameters = audit_kwargs.pop('parameters', None)
+        _, audit = self.create_audit(
+            audit_template['uuid'],
+            audit_type=audit_type,
+            state=state,
+            interval=interval,
+            parameters=parameters)
+
+        try:
+            self.assertTrue(test_utils.call_until_true(
+                func=functools.partial(
+                    self.has_audit_finished, audit['uuid']),
+                duration=600,
+                sleep_for=2
+            ))
+        except ValueError:
+            self.fail("The audit has failed!")
+
+        _, finished_audit = self.client.show_audit(audit['uuid'])
+        if finished_audit.get('state') in ('FAILED', 'CANCELLED', 'SUSPENDED'):
+            self.fail("The audit ended in unexpected state: %s!"
+                      % finished_audit.get('state'))
+
+        _, action_plans = self.client.list_action_plans(
+            audit_uuid=audit['uuid'])
+        action_plan = action_plans['action_plans'][0]
+
+        _, action_plan = self.client.show_action_plan(action_plan['uuid'])
+
+        if action_plan['state'] in ('SUPERSEDED', 'SUCCEEDED'):
+            # This means the action plan is superseded so we cannot trigger it,
+            # or it is empty.
+            return
+
+        # Execute the action by changing its state to PENDING
+        _, updated_ap = self.client.start_action_plan(action_plan['uuid'])
+
+        self.assertTrue(test_utils.call_until_true(
+            func=functools.partial(
+                self.has_action_plan_finished, action_plan['uuid']),
+            duration=600,
+            sleep_for=2
+        ))
+        _, finished_ap = self.client.show_action_plan(action_plan['uuid'])
+        _, action_list = self.client.list_actions(
+            action_plan_uuid=finished_ap["uuid"])
+        self.assertIn(updated_ap['state'], ('PENDING', 'ONGOING'))
+        self.assertIn(finished_ap['state'], ('SUCCEEDED', 'SUPERSEDED'))
+
+        for action in action_list['actions']:
+            self.assertEqual('SUCCEEDED', action.get('state'))
+
+    def check_node_trait(self, node_id, trait):
+        """Check if trait is in node traits
+
+        :param node_id: The unique identifier of the node.
+        :param trait: node trait
+        :return: True if node has the trait else False
+        """
+        traits = self.placement_client.list_provider_traits(node_id)
+        if trait in traits.get('traits'):
+            return True
+        else:
+            return False
