@@ -55,6 +55,8 @@ class TestExecuteActionsViaActuator(base.BaseInfraOptimScenarioTest):
                  "migration_type": "live"},
              "filling_function": "_prerequisite_param_for_migrate_action"},
             {"action_type": "migrate",
+             "input_parameters": {
+                 "migration_type": "cold"},
              "filling_function": "_prerequisite_param_for_migrate_action"}]})
     ]
 
@@ -99,10 +101,10 @@ class TestExecuteActionsViaActuator(base.BaseInfraOptimScenarioTest):
     def _prerequisite_param_for_resize_action(self):
         created_instances = self._create_one_instance_per_host_with_statistic()
         instance = created_instances[0]
-        current_flavor_id = instance['flavor']['id']
+        current_flavor_name = instance['flavor']['original_name']
 
         flavors = self._get_flavors()
-        new_flavors = [f for f in flavors if f['id'] != current_flavor_id]
+        new_flavors = [f for f in flavors if f['name'] != current_flavor_name]
         new_flavor = new_flavors[0]
 
         parameters = {
@@ -192,73 +194,6 @@ class TestExecuteActionsViaActuator(base.BaseInfraOptimScenarioTest):
 
         self.assertEqual(expected_action_counter, action_counter)
 
-    def test_execute_nop(self):
-        self.addCleanup(self.rollback_compute_nodes_status)
-
-        actions = [{
-            "action_type": "nop",
-            "input_parameters": {"message": "hello World"}}]
-        self._execute_actions(actions)
-
-    def test_execute_sleep(self):
-        self.addCleanup(self.rollback_compute_nodes_status)
-
-        actions = [
-            {"action_type": "sleep",
-             "input_parameters": {"duration": 1.0}}
-        ]
-        self._execute_actions(actions)
-
-    def test_execute_change_nova_service_state(self):
-        self.addCleanup(self.rollback_compute_nodes_status)
-
-        enabled_compute_nodes = [
-            cn for cn in self.initial_compute_nodes_setup
-            if cn.get('status') == 'enabled']
-
-        enabled_compute_node = enabled_compute_nodes[0]
-        actions = [
-            {"action_type": "change_nova_service_state",
-             "resource_id": enabled_compute_node['host'],
-             "input_parameters": {"state": "enabled"}}
-        ]
-        self._execute_actions(actions)
-
-    def test_execute_resize(self):
-        self.addCleanup(self.rollback_compute_nodes_status)
-
-        created_instances = self._create_one_instance_per_host_with_statistic()
-        instance = created_instances[0]
-        current_flavor_id = instance['flavor']['id']
-
-        flavors = self._get_flavors()
-        new_flavors = [f for f in flavors if f['id'] != current_flavor_id]
-        new_flavor = new_flavors[0]
-
-        actions = [
-            {"action_type": "resize",
-             "resource_id": instance['id'],
-             "input_parameters": {"flavor": new_flavor['name']}}
-        ]
-        self._execute_actions(actions)
-
-    def test_execute_migrate(self):
-        self.addCleanup(self.rollback_compute_nodes_status)
-
-        created_instances = self._create_one_instance_per_host_with_statistic()
-        instance = created_instances[0]
-        source_node = created_instances[0]["OS-EXT-SRV-ATTR:host"]
-        destination_node = created_instances[-1]["OS-EXT-SRV-ATTR:host"]
-        actions = [
-            {"action_type": "migrate",
-             "resource_id": instance['id'],
-             "input_parameters": {
-                 "migration_type": "live",
-                 "source_node": source_node,
-                 "destination_node": destination_node}}
-        ]
-        self._execute_actions(actions)
-
     def test_execute_scenarios(self):
         self.addCleanup(self.rollback_compute_nodes_status)
 
